@@ -17,7 +17,8 @@ class NotifyConfigAdmin(SingletonModelAdmin):
             'fields': ('sms_url', 'sms_api_id', 'sms_from')
         }),
         ('Telegram', {
-            'fields': ('telegram_api_key',)
+            'fields': ('telegram_api_key', 'telegram_bot_name', 'telegram_welcome_text', 'telegram_help_text', 'telegram_bad_command_text',
+                       'telegram_success_added_text', 'telegram_failed_added_text')
         }),
         ('Viber', {
             'fields': ('viber_api_key', 'viber_bot_name', 'viber_success_added_text',
